@@ -2,6 +2,7 @@ library(pins)
 library(plumber)
 skip_if_not_installed("workflows")
 skip_if_not_installed("parsnip")
+skip_if_not_installed("ranger")
 
 library(workflows)
 library(parsnip)
@@ -66,10 +67,13 @@ test_that("default OpenAPI spec", {
 
 test_that("create plumber.R for xgboost", {
     skip_on_cran()
-    b <- board_folder(path = "/tmp/test")
+    b <- board_folder(path = tmp_dir)
     vetiver_pin_write(b, v)
     tmp <- tempfile()
     vetiver_write_plumber(b, "cars_wf", file = tmp)
-    expect_snapshot(cat(readr::read_lines(tmp), sep = "\n"))
+    expect_snapshot(
+        cat(readr::read_lines(tmp), sep = "\n"),
+        transform = redact_vetiver
+    )
 })
 
