@@ -1,15 +1,9 @@
 library(pins)
 
-b <- board_folder(path = "/tmp/test")
-tmp_dir <- normalizePath(withr::local_tempdir(), winslash = "/")
+b <- board_folder(path = tmp_dir)
 cars_lm <- lm(mpg ~ cyl + disp, data = mtcars)
 v <- vetiver_model(cars_lm, "cars1")
 
-redact_docker <- function(dockerfile) {
-    dockerfile <- gsub(tmp_dir, "<redacted>", dockerfile)
-    dockerfile <- gsub(getRversion(), "<r_version>", dockerfile)
-}
-
 test_that("create Dockerfile with packages", {
     skip_on_cran()
     v$metadata$required_pkgs <- c("beepr", "caret")
@@ -18,7 +12,7 @@ test_that("create Dockerfile with packages", {
     vetiver_write_docker(v, file.path(tmp_dir, "plumber.R"), tmp_dir)
     expect_snapshot(
         cat(readr::read_lines(file.path(tmp_dir, "Dockerfile")), sep = "\n"),
-        transform = redact_docker
+        transform = redact_vetiver
     )
 })
 
@@ -29,6 +23,6 @@ test_that("create Dockerfile with no packages", {
     vetiver_write_docker(v, file.path(tmp_dir, "plumber.R"), tmp_dir)
     expect_snapshot(
         cat(readr::read_lines(file.path(tmp_dir, "Dockerfile")), sep = "\n"),
-        transform = redact_docker
+        transform = redact_vetiver
     )
 })
